@@ -31,7 +31,7 @@ def pull():
 def run():
     config = json.load(open(f"/home/{os.getlogin()}/skynix/config.json"))
     python = config["python"]
-    os.system(f"{python} /home/{os.getlogin()}/skynix/main.py")
+    os.system(f'cd /home/{os.getlogin()}/skynix && pipenv shell && python -u "/home/{os.getlogin()}/skynix/main.py"')
 
 @cli.command()
 def config():
